==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ScatterTriangulationSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TriangulationStatusEventArgsDescriptionMetadata } from "./TriangulationStatusEventArgsDescriptionMetadata";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
/**
 * @hidden
 */
var ScatterTriangulationSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterTriangulationSeriesDescriptionMetadata, _super);
    function ScatterTriangulationSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ScatterTriangulationSeriesDescriptionMetadata.b = function (a) {
        if (ScatterTriangulationSeriesDescriptionMetadata.a == null) {
            ScatterTriangulationSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ScatterTriangulationSeriesDescriptionMetadata.c(ScatterTriangulationSeriesDescriptionMetadata.a);
        }
        if (a.j(ScatterTriangulationSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(ScatterTriangulationSeriesDescriptionMetadata.a);
        TriangulationStatusEventArgsDescriptionMetadata.d(a);
    };
    ScatterTriangulationSeriesDescriptionMetadata.c = function (a) {
        SeriesDescriptionMetadata.c(a);
        a.item("XMemberPath", "String");
        a.item("YMemberPath", "String");
        a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
        a.item("XAxisRef@nameBinding", "true");
        a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
        a.item("YAxisRef@nameBinding", "true");
        a.item("TrianglesSourceRef", "(w:TrianglesSource,wf:TrianglesSource)DataRef::object");
        a.item("TriangleVertexMemberPath1", "String");
        a.item("TriangleVertexMemberPath2", "String");
        a.item("TriangleVertexMemberPath3", "String");
        a.item("XMemberAsLegendLabel", "String");
        a.item("YMemberAsLegendLabel", "String");
        a.item("XMemberAsLegendUnit", "String");
        a.item("YMemberAsLegendUnit", "String");
        a.item("TriangulationStatusChangedRef", "EventRef::triangulationStatusChanged");
    };
    ScatterTriangulationSeriesDescriptionMetadata.d = function (a) {
        ScatterTriangulationSeriesDescriptionMetadata.b(a);
        a.z("ScatterTriangulationSeries", ScatterTriangulationSeriesDescriptionMetadata.a);
    };
    ScatterTriangulationSeriesDescriptionMetadata.$t = markType(ScatterTriangulationSeriesDescriptionMetadata, 'ScatterTriangulationSeriesDescriptionMetadata');
    ScatterTriangulationSeriesDescriptionMetadata.a = null;
    return ScatterTriangulationSeriesDescriptionMetadata;
}(Base));
export { ScatterTriangulationSeriesDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/ScatterTriangulationSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TriangulationStatusEventArgsDescriptionMetadata } from "./TriangulationStatusEventArgsDescriptionMetadata";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
/**
 * @hidden
 */
var ScatterTriangulationSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterTriangulationSeriesDescriptionMetadata, _super);
    function ScatterTriangulationSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ScatterTriangulationSeriesDescriptionMetadata.b = function (a) {
        if (ScatterTriangulationSeriesDescriptionMetadata.a == null) {
            ScatterTriangulationSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ScatterTriangulationSeriesDescriptionMetadata.c(ScatterTriangulationSeriesDescriptionMetadata.a);
        }
        if (a.k(ScatterTriangulationSeriesDescriptionMetadata.a)) {
            return;
        }
        a.aa(ScatterTriangulationSeriesDescriptionMetadata.a);
        TriangulationStatusEventArgsDescriptionMetadata.d(a);
    };
    ScatterTriangulationSeriesDescriptionMetadata.c = function (a) {
        SeriesDescriptionMetadata.c(a);
        a.item("XMemberPath", "String");
        a.item("YMemberPath", "String");
        a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
        a.item("XAxisRef@nameBinding", "true");
        a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
        a.item("YAxisRef@nameBinding", "true");
        a.item("TrianglesSourceRef", "(w:TrianglesSource,wf:TrianglesSource)DataRef::object");
        a.item("TriangleVertexMemberPath1", "String");
        a.item("TriangleVertexMemberPath2", "String");
        a.item("TriangleVertexMemberPath3", "String");
        a.item("XMemberAsLegendLabel", "String");
        a.item("YMemberAsLegendLabel", "String");
        a.item("XMemberAsLegendUnit", "String");
        a.item("YMemberAsLegendUnit", "String");
        a.item("TriangulationStatusChangedRef", "EventRef::triangulationStatusChanged");
    };
    ScatterTriangulationSeriesDescriptionMetadata.d = function (a) {
        ScatterTriangulationSeriesDescriptionMetadata.b(a);
        a.ab("ScatterTriangulationSeries", ScatterTriangulationSeriesDescriptionMetadata.a);
    };
    ScatterTriangulationSeriesDescriptionMetadata.$t = markType(ScatterTriangulationSeriesDescriptionMetadata, 'ScatterTriangulationSeriesDescriptionMetadata');
    ScatterTriangulationSeriesDescriptionMetadata.a = null;
    return ScatterTriangulationSeriesDescriptionMetadata;
}(Base));
export { ScatterTriangulationSeriesDescriptionMetadata };
